.. code-block:: bash

   Usage: nessie remote [OPTIONS] COMMAND [ARGS]...

     Set and view remote endpoint.

   Options:
     --help  Show this message and exit.

   Commands:
     add       Set current remote.
     set-head  Set current default branch.
     show      Show current remote.


It contains the following sub-commands:

Remote Show Command
~~~~~~~~~

.. include:: remote_show.rst

Remote Add Command
~~~~~~~~~

.. include:: remote_add.rst

Remote Set-head Command
~~~~~~~~~

.. include:: remote_set-head.rst

